@@ -1,5 +1,5 @@
 import sys
-from qt_command_palette import CommandPalette
+from qt_command_palette import get_palette, get_storage
 
 
 def define(text: str):
@@ -18,7 +18,13 @@ if __name__ == "__main__":
     main = QWidget()
     main.setMinimumSize(400, 300)
 
-    palette = CommandPalette()
+    palette = get_palette(name=__name__)
+    storage = get_storage(name=__name__)
+
+    @storage.mark_getter("widget")
+    def get_widget():
+        return main
+
     group_0 = palette.add_group("Example")
     group_1 = palette.add_group("Something new")
 
@@ -28,6 +34,10 @@ if __name__ == "__main__":
     for txt in ["hello world", "goobye world", "hello again"]:
         group_1.register(define(txt))
 
+    @group_1.register("Print widget")
+    def print_widget(widget: QWidget):
+        print(widget)
+
     palette.install(main, "Ctrl+Shift+P")
     main.show()
     sys.exit(app.exec_())
